<?php

namespace common\logic\Distribution\Distribution\Module;

use common\logic\AbstractManager;
use common\logic\AbstractModule;
use common\logic\Distribution\Distribution\Repository\DistributionRepository;
use common\logic\Distribution\Distribution\Service\DistributionBuilder;
use common\logic\Distribution\Distribution\Service\DistributionDefinition;
use common\logic\Distribution\Distribution\Service\DistributionReportCsvGenerator;
use common\logic\Distribution\Distribution\Service\DistributionReportGridPdfGenerator;
use common\logic\Distribution\Distribution\Service\DistributionReportPdfGenerator;
use common\logic\Distribution\Distribution\Service\DistributionShoppingCartLabelsPdfGenerator;
use common\logic\Distribution\Distribution\Service\DistributionSolver;

/**
 * @mixin DistributionDefinition
 * @mixin DistributionSolver
 * @mixin DistributionRepository
 * @mixin DistributionBuilder
 * @mixin DistributionReportCsvGenerator
 * @mixin DistributionReportGridPdfGenerator
 * @mixin DistributionReportPdfGenerator
 * @mixin DistributionShoppingCartLabelsPdfGenerator
 */
class DistributionModule extends AbstractModule
{
    public function getServices(): array
    {
        return [
            DistributionDefinition::class,
            DistributionSolver::class,
            DistributionRepository::class,
            DistributionBuilder::class,
            DistributionReportCsvGenerator::class,
            DistributionReportGridPdfGenerator::class,
            DistributionReportPdfGenerator::class,
            DistributionShoppingCartLabelsPdfGenerator::class
        ];
    }

    public function getDefinition(): DistributionDefinition
    {
        return DistributionDefinition::getInstance();
    }

    public function getSolver(): DistributionSolver
    {
        return DistributionSolver::getInstance();
    }

    public function getRepository(): DistributionRepository
    {
        return DistributionRepository::getInstance();
    }

    public function getBuilder(): DistributionBuilder
    {
        return DistributionBuilder::getInstance();
    }

    public function getReportCsvGenerator(): DistributionReportCsvGenerator
    {
        return DistributionReportCsvGenerator::getInstance();
    }

    public function getReportGridPdfGenerator(): DistributionReportGridPdfGenerator
    {
        return DistributionReportGridPdfGenerator::getInstance();
    }

    public function getReportPdfGenerator(): DistributionReportPdfGenerator
    {
        return DistributionReportPdfGenerator::getInstance();
    }

    public function getShoppingCartLabelsPdfGenerator(): DistributionShoppingCartLabelsPdfGenerator
    {
        return DistributionShoppingCartLabelsPdfGenerator::getInstance();
    }
}